complete -c atuin -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c atuin -n "__fish_use_subcommand" -f -a "history" -d 'Manipulate shell history'
complete -c atuin -n "__fish_use_subcommand" -f -a "import" -d 'Import shell history from file'
complete -c atuin -n "__fish_use_subcommand" -f -a "stats" -d 'Calculate statistics for your history'
complete -c atuin -n "__fish_use_subcommand" -f -a "search" -d 'Interactive history search'
complete -c atuin -n "__fish_use_subcommand" -f -a "sync" -d 'Sync with the configured server'
complete -c atuin -n "__fish_use_subcommand" -f -a "login" -d 'Login to the configured server'
complete -c atuin -n "__fish_use_subcommand" -f -a "logout" -d 'Log out'
complete -c atuin -n "__fish_use_subcommand" -f -a "register" -d 'Register with the configured server'
complete -c atuin -n "__fish_use_subcommand" -f -a "key" -d 'Print the encryption key for transfer to another machine'
complete -c atuin -n "__fish_use_subcommand" -f -a "status" -d 'Display the sync status'
complete -c atuin -n "__fish_use_subcommand" -f -a "account" -d 'Manage your sync account'
complete -c atuin -n "__fish_use_subcommand" -f -a "kv" -d 'Get or set small key-value pairs'
complete -c atuin -n "__fish_use_subcommand" -f -a "store" -d 'Manage the atuin data store'
complete -c atuin -n "__fish_use_subcommand" -f -a "dotfiles" -d 'Manage your dotfiles with Atuin'
complete -c atuin -n "__fish_use_subcommand" -f -a "init" -d 'Print Atuin\'s shell init script'
complete -c atuin -n "__fish_use_subcommand" -f -a "info" -d 'Information about dotfiles locations and ENV vars'
complete -c atuin -n "__fish_use_subcommand" -f -a "doctor" -d 'Run the doctor to check for common issues'
complete -c atuin -n "__fish_use_subcommand" -f -a "default-config" -d 'Print example configuration'
complete -c atuin -n "__fish_use_subcommand" -f -a "server" -d 'Start an atuin server'
complete -c atuin -n "__fish_use_subcommand" -f -a "uuid" -d 'Generate a UUID'
complete -c atuin -n "__fish_use_subcommand" -f -a "contributors"
complete -c atuin -n "__fish_use_subcommand" -f -a "gen-completions" -d 'Generate shell completions'
complete -c atuin -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "start" -d 'Begins a new command in the history'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "end" -d 'Finishes a new command in the history (adds time, exit code)'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all items in history'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "last" -d 'Get the last command ran'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "init-store"
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "prune" -d 'Delete history entries matching the configured exclusion filters'
complete -c atuin -n "__fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from start" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from end" -s e -l exit -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from end" -s d -l duration -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from end" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -s r -l reverse -r -f -a "{true	'',false	''}"
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -l timezone -l tz -d 'Display the command time in another timezone other than the configured default' -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -s f -l format -d 'Available variables: {command}, {directory}, {duration}, {user}, {host}, {exit} and {time}. Example: --format "{time} - [{duration}] - {directory}$\\t{command}"' -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -s c -l cwd
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -s s -l session
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -l human
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -l cmd-only -d 'Show only the text of the command'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -l print0 -d 'Terminate the output with a null, for better multiline support'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from last" -l timezone -l tz -d 'Display the command time in another timezone other than the configured default' -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from last" -s f -l format -d 'Available variables: {command}, {directory}, {duration}, {user}, {host} and {time}. Example: --format "{time} - [{duration}] - {directory}$\\t{command}"' -r
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from last" -l human
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from last" -l cmd-only -d 'Show only the text of the command'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from last" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from init-store" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from prune" -s n -l dry-run -d 'List matching history lines without performing the actual deletion'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from prune" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "start" -d 'Begins a new command in the history'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "end" -d 'Finishes a new command in the history (adds time, exit code)'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all items in history'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "last" -d 'Get the last command ran'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "init-store"
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "prune" -d 'Delete history entries matching the configured exclusion filters'
complete -c atuin -n "__fish_seen_subcommand_from history; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "auto" -d 'Import history for the current shell'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "zsh" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "zsh-hist-db" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "bash" -d 'Import history from the bash history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "resh" -d 'Import history from the resh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "fish" -d 'Import history from the fish history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "nu" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "nu-hist-db" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "xonsh" -d 'Import history from xonsh json files'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "xonsh-sqlite" -d 'Import history from xonsh sqlite db'
complete -c atuin -n "__fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from auto" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from zsh" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from zsh-hist-db" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from bash" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from resh" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from fish" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from nu" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from nu-hist-db" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from xonsh" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from xonsh-sqlite" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "auto" -d 'Import history for the current shell'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "zsh" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "zsh-hist-db" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "bash" -d 'Import history from the bash history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "resh" -d 'Import history from the resh history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "fish" -d 'Import history from the fish history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "nu" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "nu-hist-db" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "xonsh" -d 'Import history from xonsh json files'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "xonsh-sqlite" -d 'Import history from xonsh sqlite db'
complete -c atuin -n "__fish_seen_subcommand_from import; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from stats" -s c -l count -d 'How many top commands to list' -r
complete -c atuin -n "__fish_seen_subcommand_from stats" -s n -l ngram-size -d 'The number of consecutive commands to consider' -r
complete -c atuin -n "__fish_seen_subcommand_from stats" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from search" -s c -l cwd -d 'Filter search result by directory' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l exclude-cwd -d 'Exclude directory from results' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -s e -l exit -d 'Filter search result by exit code' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l exclude-exit -d 'Exclude results with this exit code' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -s b -l before -d 'Only include results added before this date' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l after -d 'Only include results after this date' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l limit -d 'How many entries to return at most' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l offset -d 'Offset from the start of the results' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l filter-mode -d 'Allow overriding filter mode over config' -r -f -a "{global	'',host	'',session	'',directory	'',workspace	''}"
complete -c atuin -n "__fish_seen_subcommand_from search" -l search-mode -d 'Allow overriding search mode over config' -r -f -a "{prefix	'',full-text	'',fuzzy	'',skim	''}"
complete -c atuin -n "__fish_seen_subcommand_from search" -l keymap-mode -d 'Notify the keymap at the shell\'s side' -r -f -a "{emacs	'',vim-normal	'',vim-insert	'',auto	''}"
complete -c atuin -n "__fish_seen_subcommand_from search" -l timezone -l tz -d 'Display the command time in another timezone other than the configured default' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -s f -l format -d 'Available variables: {command}, {directory}, {duration}, {user}, {host}, {time}, {exit} and {relativetime}. Example: --format "{time} - [{duration}] - {directory}$\\t{command}"' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -l inline-height -d 'Set the maximum number of lines Atuin\'s interface should take up' -r
complete -c atuin -n "__fish_seen_subcommand_from search" -s i -l interactive -d 'Open interactive search UI'
complete -c atuin -n "__fish_seen_subcommand_from search" -l shell-up-key-binding -d 'Marker argument used to inform atuin that it was invoked from a shell up-key binding (hidden from help to avoid confusion)'
complete -c atuin -n "__fish_seen_subcommand_from search" -l human -d 'Use human-readable formatting for time'
complete -c atuin -n "__fish_seen_subcommand_from search" -l cmd-only -d 'Show only the text of the command'
complete -c atuin -n "__fish_seen_subcommand_from search" -l delete -d 'Delete anything matching this query. Will not print out the match'
complete -c atuin -n "__fish_seen_subcommand_from search" -l delete-it-all -d 'Delete EVERYTHING!'
complete -c atuin -n "__fish_seen_subcommand_from search" -s r -l reverse -d 'Reverse the order of results, oldest first'
complete -c atuin -n "__fish_seen_subcommand_from search" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c atuin -n "__fish_seen_subcommand_from sync" -s f -l force -d 'Force re-download everything'
complete -c atuin -n "__fish_seen_subcommand_from sync" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from login" -s u -l username -r
complete -c atuin -n "__fish_seen_subcommand_from login" -s p -l password -r
complete -c atuin -n "__fish_seen_subcommand_from login" -s k -l key -d 'The encryption key for your account' -r
complete -c atuin -n "__fish_seen_subcommand_from login" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from logout" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from register" -s u -l username -r
complete -c atuin -n "__fish_seen_subcommand_from register" -s p -l password -r
complete -c atuin -n "__fish_seen_subcommand_from register" -s e -l email -r
complete -c atuin -n "__fish_seen_subcommand_from register" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from key" -l base64 -d 'Switch to base64 output of the key'
complete -c atuin -n "__fish_seen_subcommand_from key" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Login to the configured server'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "register"
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "logout" -d 'Log out'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete your account, and all synced data'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "change-password" -d 'Change your password'
complete -c atuin -n "__fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s u -l username -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s p -l password -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s k -l key -d 'The encryption key for your account' -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from login" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from register" -s u -l username -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from register" -s p -l password -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from register" -s e -l email -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from register" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from logout" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from change-password" -s c -l current-password -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from change-password" -s n -l new-password -r
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from change-password" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Login to the configured server'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "register"
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "logout" -d 'Log out'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete your account, and all synced data'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "change-password" -d 'Change your password'
complete -c atuin -n "__fish_seen_subcommand_from account; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "set"
complete -c atuin -n "__fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "get"
complete -c atuin -n "__fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c atuin -n "__fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from set" -s k -l key -r
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from set" -s n -l namespace -r
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from get" -s n -l namespace -r
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from get" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from list" -s n -l namespace -r
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from list" -s a -l all-namespaces
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "set"
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "get"
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "list"
complete -c atuin -n "__fish_seen_subcommand_from kv; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "status"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "rebuild"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "rekey"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "purge"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "verify"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "push"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "pull"
complete -c atuin -n "__fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from rebuild" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from rekey" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from purge" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from verify" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from push" -s t -l tag -d 'The tag to push (eg, \'history\'). Defaults to all tags' -r
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from push" -l host -d 'The host to push, in the form of a UUID host ID. Defaults to the current host' -r
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from push" -l force -d 'Force push records This will override both host and tag, to be all hosts and all tags. First clear the remote store, then upload all of the local store'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from push" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from pull" -s t -l tag -d 'The tag to push (eg, \'history\'). Defaults to all tags' -r
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from pull" -l force -d 'Force push records This will first wipe the local store, and then download all records from the remote'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from pull" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "status"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "rebuild"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "rekey"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "purge"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "verify"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "push"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "pull"
complete -c atuin -n "__fish_seen_subcommand_from store; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from help" -f -a "alias" -d 'Manage shell aliases with Atuin'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all aliases'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "import" -d 'Import aliases set in the current shell'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from import" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "set" -d 'Set an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "list" -d 'List all aliases'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "import" -d 'Import aliases set in the current shell'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from help" -f -a "alias" -d 'Manage shell aliases with Atuin'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "set" -d 'Set an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "delete" -d 'Delete an alias'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "list" -d 'List all aliases'
complete -c atuin -n "__fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from help; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "import" -d 'Import aliases set in the current shell'
complete -c atuin -n "__fish_seen_subcommand_from init" -l disable-ctrl-r -d 'Disable the binding of CTRL-R to atuin'
complete -c atuin -n "__fish_seen_subcommand_from init" -l disable-up-arrow -d 'Disable the binding of the Up Arrow key to atuin'
complete -c atuin -n "__fish_seen_subcommand_from init" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c atuin -n "__fish_seen_subcommand_from info" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from doctor" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from default-config" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "start" -d 'Start the server'
complete -c atuin -n "__fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "default-config" -d 'Print server example configuration'
complete -c atuin -n "__fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from start" -l host -d 'The host address to bind' -r
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from start" -s p -l port -d 'The port to bind' -r
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from start" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from default-config" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "start" -d 'Start the server'
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "default-config" -d 'Print server example configuration'
complete -c atuin -n "__fish_seen_subcommand_from server; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from uuid" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from contributors" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from gen-completions" -s s -l shell -d 'Set the shell for generating completions' -r -f -a "{bash	'',elvish	'',fish	'',nushell	'',powershell	'',zsh	''}"
complete -c atuin -n "__fish_seen_subcommand_from gen-completions" -s o -l out-dir -d 'Set the output directory' -r
complete -c atuin -n "__fish_seen_subcommand_from gen-completions" -s h -l help -d 'Print help'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "history" -d 'Manipulate shell history'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "import" -d 'Import shell history from file'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "stats" -d 'Calculate statistics for your history'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "search" -d 'Interactive history search'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "sync" -d 'Sync with the configured server'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "login" -d 'Login to the configured server'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "logout" -d 'Log out'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "register" -d 'Register with the configured server'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "key" -d 'Print the encryption key for transfer to another machine'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "status" -d 'Display the sync status'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "account" -d 'Manage your sync account'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "kv" -d 'Get or set small key-value pairs'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "store" -d 'Manage the atuin data store'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "dotfiles" -d 'Manage your dotfiles with Atuin'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "init" -d 'Print Atuin\'s shell init script'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "info" -d 'Information about dotfiles locations and ENV vars'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "doctor" -d 'Run the doctor to check for common issues'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "default-config" -d 'Print example configuration'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "server" -d 'Start an atuin server'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "uuid" -d 'Generate a UUID'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "contributors"
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "gen-completions" -d 'Generate shell completions'
complete -c atuin -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from stats; and not __fish_seen_subcommand_from search; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from key; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from init; and not __fish_seen_subcommand_from info; and not __fish_seen_subcommand_from doctor; and not __fish_seen_subcommand_from default-config; and not __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from uuid; and not __fish_seen_subcommand_from contributors; and not __fish_seen_subcommand_from gen-completions; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "start" -d 'Begins a new command in the history'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "end" -d 'Finishes a new command in the history (adds time, exit code)'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "list" -d 'List all items in history'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "last" -d 'Get the last command ran'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "init-store"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from history; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from end; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from last; and not __fish_seen_subcommand_from init-store; and not __fish_seen_subcommand_from prune" -f -a "prune" -d 'Delete history entries matching the configured exclusion filters'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "auto" -d 'Import history for the current shell'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "zsh" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "zsh-hist-db" -d 'Import history from the zsh history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "bash" -d 'Import history from the bash history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "resh" -d 'Import history from the resh history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "fish" -d 'Import history from the fish history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "nu" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "nu-hist-db" -d 'Import history from the nu history file'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "xonsh" -d 'Import history from xonsh json files'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from import; and not __fish_seen_subcommand_from auto; and not __fish_seen_subcommand_from zsh; and not __fish_seen_subcommand_from zsh-hist-db; and not __fish_seen_subcommand_from bash; and not __fish_seen_subcommand_from resh; and not __fish_seen_subcommand_from fish; and not __fish_seen_subcommand_from nu; and not __fish_seen_subcommand_from nu-hist-db; and not __fish_seen_subcommand_from xonsh; and not __fish_seen_subcommand_from xonsh-sqlite" -f -a "xonsh-sqlite" -d 'Import history from xonsh sqlite db'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password" -f -a "login" -d 'Login to the configured server'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password" -f -a "register"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password" -f -a "logout" -d 'Log out'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password" -f -a "delete" -d 'Delete your account, and all synced data'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from account; and not __fish_seen_subcommand_from login; and not __fish_seen_subcommand_from register; and not __fish_seen_subcommand_from logout; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from change-password" -f -a "change-password" -d 'Change your password'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list" -f -a "set"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list" -f -a "get"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from kv; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from get; and not __fish_seen_subcommand_from list" -f -a "list"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "status"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "rebuild"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "rekey"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "purge"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "verify"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "push"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from store; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from rebuild; and not __fish_seen_subcommand_from rekey; and not __fish_seen_subcommand_from purge; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from push; and not __fish_seen_subcommand_from pull" -f -a "pull"
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dotfiles; and not __fish_seen_subcommand_from alias" -f -a "alias" -d 'Manage shell aliases with Atuin'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "set" -d 'Set an alias'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "delete" -d 'Delete an alias'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "list" -d 'List all aliases'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from dotfiles; and __fish_seen_subcommand_from alias; and not __fish_seen_subcommand_from set; and not __fish_seen_subcommand_from delete; and not __fish_seen_subcommand_from list; and not __fish_seen_subcommand_from import" -f -a "import" -d 'Import aliases set in the current shell'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config" -f -a "start" -d 'Start the server'
complete -c atuin -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from server; and not __fish_seen_subcommand_from start; and not __fish_seen_subcommand_from default-config" -f -a "default-config" -d 'Print server example configuration'
